@@ -1,17 +1,13 @@
 package  # hide from PAUSE
    P9Y::ProcessTable;
 
-our $VERSION = '0.95_004'; # VERSION
+our $VERSION = '0.90'; # VERSION
+# ABSTRACT: VMS process table
 
 #############################################################################
 # Modules
 
-# use sanity;
-use strict qw(subs vars);
-no strict 'refs';
-use warnings FATAL => 'all';
-no warnings qw(uninitialized);
-
+use sanity;
 use Moo;
 use P9Y::ProcessTable::Process;
 
@@ -25,7 +21,7 @@ no warnings 'uninitialized';
 
 sub table {
    my $self = shift;
-   return map {
+   return map { 
       my $hash = $self->_convert_hash($_);
       $hash->{_pt_obj} = $self;
       P9Y::ProcessTable::Process->new($hash);
@@ -37,15 +33,6 @@ sub list {
    return sort { $a <=> $b } map { $_->{PID} } (process_list);
 }
 
-sub fields {
-   return ( qw/
-      pid uid gid ppid pgrp
-      exe
-      ttlflt start time
-      priority fname state ttydev flags size rss cpuid
-   / );
-}
-
 sub _process_hash {
    my ($self, $pid) = @_;
    my $info = process_list({
@@ -59,9 +46,9 @@ sub _process_hash {
 sub _convert_hash {
    my ($self, $info) = @_;
    return unless $info;
-
+   
    my $hash = {};
-   my $stat_loc = { qw/
+   state $stat_loc = { qw/
       pid         PID
       uid         OWNER
       gid         GRP
@@ -70,7 +57,7 @@ sub _convert_hash {
       cpuid       CPUID
       priority    PRI
       flags       PHDFLAGS
-      ttlflt      PAGEFLTS
+      minflt      PAGEFLTS
       time        CPUTIM
       size        VIRTPEAK
       rss         WSSIZE
@@ -91,3 +78,35 @@ sub _convert_hash {
 }
 
 42;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+P9Y::ProcessTable - VMS process table
+
+=head1 AVAILABILITY
+
+The project homepage is L<https://github.com/SineSwiper/P9Y-ProcessTable/wiki>.
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<https://metacpan.org/module/P9Y::ProcessTable/>.
+
+=head1 AUTHOR
+
+Brendan Byrd <BBYRD@CPAN.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Brendan Byrd.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
+
